==========================
django-reporting-endpoints
==========================

.. image:: https://img.shields.io/readthedocs/django-reporting-endpoints?style=for-the-badge
   :target: https://django-reporting-endpoints.readthedocs.io/en/latest/

.. image:: https://img.shields.io/github/actions/workflow/status/seporaitis/django-reporting-endpoints/main.yml?branch=main&style=for-the-badge
   :target: https://github.com/seporaitis/django-reporting-endpoints/actions?workflow=CI

.. image:: https://img.shields.io/badge/Coverage-100%25-success?style=for-the-badge
   :target: https://github.com/seporaitis/django-reporting-endpoints/actions?workflow=CI

.. image:: https://img.shields.io/pypi/v/django-reporting-endpoints.svg?style=for-the-badge
   :target: https://pypi.org/project/django-reporting-endpoints/

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=for-the-badge
   :target: https://github.com/psf/black

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=for-the-badge
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit

Django app for receiving browser's `Reporting API <https://www.w3.org/TR/reporting-1/>`__ reports.

Documentation
-------------

Please see https://django-reporting-endpoints.readthedocs.io/ .
